@@ -28,7 +28,6 @@ class Grid(object):
         """Set attributes on each subplot Axes."""
         for ax in self.axes.flat:
             ax.set(**kwargs)
-
         return self
 
     def savefig(self, *args, **kwargs):
@@ -50,7 +49,7 @@ class Grid(object):
             Title for the legend. The default reads from ``self._hue_var``.
         label_order : list of labels, optional
             The order that the legend entries should appear in. The default
-            reads from ``self.hue_names`` or sorts the keys in ``legend_data``.
+            reads from ``self.hue_names``.
         kwargs : key, value pairings
             Other keyword arguments are passed to the underlying legend methods
             on the Figure or Axes object.
@@ -65,7 +64,7 @@ class Grid(object):
         legend_data = self._legend_data if legend_data is None else legend_data
         if label_order is None:
             if self.hue_names is None:
-                label_order = np.sort(list(legend_data.keys()))
+                label_order = list(legend_data.keys())
             else:
                 label_order = list(map(utils.to_utf8, self.hue_names))
 
@@ -81,31 +80,31 @@ class Grid(object):
         kwargs.setdefault("scatterpoints", 1)
 
         if self._legend_out:
+
+            kwargs.setdefault("frameon", False)
+
             # Draw a full-figure legend outside the grid
             figlegend = self.fig.legend(handles, label_order, "center right",
                                         **kwargs)
             self._legend = figlegend
-            figlegend.set_title(title)
-
-            # Set the title size a roundabout way to maintain
-            # compatability with matplotlib 1.1
-            prop = mpl.font_manager.FontProperties(size=title_size)
-            figlegend._legend_title_box._text.set_font_properties(prop)
+            figlegend.set_title(title, prop={"size": title_size})
 
             # Draw the plot to set the bounding boxes correctly
-            self.fig.draw(self.fig.canvas.get_renderer())
+            if hasattr(self.fig.canvas, "get_renderer"):
+                self.fig.draw(self.fig.canvas.get_renderer())
 
             # Calculate and set the new width of the figure so the legend fits
             legend_width = figlegend.get_window_extent().width / self.fig.dpi
-            figure_width = self.fig.get_figwidth()
-            self.fig.set_figwidth(figure_width + legend_width)
+            fig_width, fig_height = self.fig.get_size_inches()
+            self.fig.set_size_inches(fig_width + legend_width, fig_height)
 
             # Draw the plot again to get the new transformations
-            self.fig.draw(self.fig.canvas.get_renderer())
+            if hasattr(self.fig.canvas, "get_renderer"):
+                self.fig.draw(self.fig.canvas.get_renderer())
 
             # Now calculate how much space we need on the right side
             legend_width = figlegend.get_window_extent().width / self.fig.dpi
-            space_needed = legend_width / (figure_width + legend_width)
+            space_needed = legend_width / (fig_width + legend_width)
             margin = .04 if self._margin_titles else .01
             self._space_needed = margin + space_needed
             right = 1 - self._space_needed
@@ -117,12 +116,7 @@ class Grid(object):
             # Draw a legend in the first axis
             ax = self.axes.flat[0]
             leg = ax.legend(handles, label_order, loc="best", **kwargs)
-            leg.set_title(title)
-
-            # Set the title size a roundabout way to maintain
-            # compatability with matplotlib 1.1
-            prop = mpl.font_manager.FontProperties(size=title_size)
-            leg._legend_title_box._text.set_font_properties(prop)
+            leg.set_title(title, prop={"size": title_size})
 
         return self
 
@@ -183,17 +177,17 @@ _facet_docs = dict(
         span multiple rows. Incompatible with a ``row`` facet.\
     """),
     share_xy=dedent("""\
-    share{x,y} : bool, optional
+    share{x,y} : bool, 'col', or 'row' optional
         If true, the facets will share y axes across columns and/or x axes
         across rows.\
     """),
-    size=dedent("""\
-    size : scalar, optional
+    height=dedent("""\
+    height : scalar, optional
         Height (in inches) of each facet. See also: ``aspect``.\
     """),
     aspect=dedent("""\
     aspect : scalar, optional
-        Aspect ratio of each facet, so that ``aspect * size`` gives the width
+        Aspect ratio of each facet, so that ``aspect * height`` gives the width
         of each facet in inches.\
     """),
     palette=dedent("""\
@@ -217,18 +211,24 @@ _facet_docs = dict(
 
 
 class FacetGrid(Grid):
-    """Subplot grid for plotting conditional relationships."""
-
+    """Multi-plot grid for plotting conditional relationships."""
     def __init__(self, data, row=None, col=None, hue=None, col_wrap=None,
-                 sharex=True, sharey=True, size=3, aspect=1, palette=None,
+                 sharex=True, sharey=True, height=3, aspect=1, palette=None,
                  row_order=None, col_order=None, hue_order=None, hue_kws=None,
                  dropna=True, legend_out=True, despine=True,
                  margin_titles=False, xlim=None, ylim=None, subplot_kws=None,
-                 gridspec_kws=None):
+                 gridspec_kws=None, size=None):
 
         MPL_GRIDSPEC_VERSION = LooseVersion('1.4')
         OLD_MPL = LooseVersion(mpl.__version__) < MPL_GRIDSPEC_VERSION
 
+        # Handle deprecations
+        if size is not None:
+            height = size
+            msg = ("The `size` paramter has been renamed to `height`; "
+                   "please update your code.")
+            warnings.warn(msg, UserWarning)
+
         # Determine the hue facet layer information
         hue_var = hue
         if hue is None:
@@ -280,7 +280,8 @@ class FacetGrid(Grid):
 
         # Calculate the base figure size
         # This can get stretched later by a legend
-        figsize = (ncol * size * aspect, nrow * size)
+        # TODO this doesn't account for axis labels
+        figsize = (ncol * height * aspect, nrow * height)
 
         # Validate some inputs
         if col_wrap is not None:
@@ -302,7 +303,7 @@ class FacetGrid(Grid):
                           gridspec_kw=gridspec_kws)
 
             if OLD_MPL:
-                _ = kwargs.pop('gridspec_kw', None)
+                kwargs.pop('gridspec_kw', None)
                 if gridspec_kws:
                     msg = "gridspec module only available in mpl >= {}"
                     warnings.warn(msg.format(MPL_GRIDSPEC_VERSION))
@@ -378,20 +379,23 @@ class FacetGrid(Grid):
     __init__.__doc__ = dedent("""\
         Initialize the matplotlib figure and FacetGrid object.
 
-        The :class:`FacetGrid` is an object that links a Pandas DataFrame to
-        a matplotlib figure with a particular structure.
+        This class maps a dataset onto multiple axes arrayed in a grid of rows
+        and columns that correspond to *levels* of variables in the dataset.
+        The plots it produces are often called "lattice", "trellis", or
+        "small-multiple" graphics.
 
-        In particular, :class:`FacetGrid` is used to draw plots with multiple
-        Axes where each Axes shows the same relationship conditioned on
-        different levels of some variable. It's possible to condition on up to
-        three variables by assigning variables to the rows and columns of the
-        grid and using different colors for the plot elements.
+        It can also represent levels of a third varaible with the ``hue``
+        parameter, which plots different subets of data in different colors.
+        This uses color to resolve elements on a third dimension, but only
+        draws subsets on top of each other and will not tailor the ``hue``
+        parameter for the specific visualization the way that axes-level
+        functions that accept ``hue`` will.
 
-        The general approach to plotting here is called "small multiples",
-        where the same kind of plot is repeated multiple times, and the
-        specific use of small multiples to display the same relationship
-        conditioned on one ore more other variables is often called a "trellis
-        plot".
+        When using seaborn functions that infer semantic mappings from a
+        dataset, care must be taken to synchronize those mappings across
+        facets. In most cases, it will be better to use a figure-level function
+        (e.g. :func:`relplot` or :func:`catplot`) than to use
+        :class:`FacetGrid` directly.
 
         The basic workflow is to initialize the :class:`FacetGrid` object with
         the dataset and the variables that are used to structure the grid. Then
@@ -401,6 +405,8 @@ class FacetGrid(Grid):
         axis labels, use different ticks, or add a legend. See the detailed
         code examples below for more information.
 
+        See the :ref:`tutorial <grid_tutorial>` for more information.
+
         Parameters
         ----------
         {data}
@@ -410,7 +416,7 @@ class FacetGrid(Grid):
             control the order of levels of this variable.
         {col_wrap}
         {share_xy}
-        {size}
+        {height}
         {aspect}
         {palette}
         {{row,col,hue}}_order : lists, optional
@@ -439,8 +445,9 @@ class FacetGrid(Grid):
         See Also
         --------
         PairGrid : Subplot grid for plotting pairwise relationships.
+        relplot : Combine a relational plot and a :class:`FacetGrid`.
+        catplot : Combine a categorical plot and a :class:`FacetGrid`.
         lmplot : Combine a regression plot and a :class:`FacetGrid`.
-        factorplot : Combine a categorical plot and a :class:`FacetGrid`.
 
         Examples
         --------
@@ -494,12 +501,12 @@ class FacetGrid(Grid):
             >>> g = (g.map(plt.scatter, "total_bill", "tip", edgecolor="w")
             ...       .add_legend())
 
-        Change the size and aspect ratio of each facet:
+        Change the height and aspect ratio of each facet:
 
         .. plot::
             :context: close-figs
 
-            >>> g = sns.FacetGrid(tips, col="day", size=4, aspect=.5)
+            >>> g = sns.FacetGrid(tips, col="day", height=4, aspect=.5)
             >>> g = g.map(plt.hist, "total_bill", bins=bins)
 
         Specify the order for plot elements:
@@ -548,8 +555,8 @@ class FacetGrid(Grid):
         .. plot::
             :context: close-figs
 
-            >>> attend = sns.load_dataset("attention")
-            >>> g = sns.FacetGrid(attend, col="subject", col_wrap=5, size=1.5)
+            >>> att = sns.load_dataset("attention")
+            >>> g = sns.FacetGrid(att, col="subject", col_wrap=5, height=1.5)
             >>> g = g.map(plt.plot, "solutions", "score", marker=".")
 
         Define a custom bivariate function to map onto the grid:
@@ -583,7 +590,7 @@ class FacetGrid(Grid):
             ...     ax = plt.gca()
             ...     data = kwargs.pop("data")
             ...     data.plot(x=x, y=y, ax=ax, grid=False, **kwargs)
-            >>> g = sns.FacetGrid(df, col="walk", col_wrap=2, size=3.5)
+            >>> g = sns.FacetGrid(df, col="walk", col_wrap=2, height=3.5)
             >>> g = g.map_dataframe(dateplot, "date", "val")
 
         Use different axes labels after plotting:
@@ -644,22 +651,22 @@ class FacetGrid(Grid):
         data = self.data
 
         # Construct masks for the row variable
-        if self._nrow == 1 or self._col_wrap is not None:
-            row_masks = [np.repeat(True, len(self.data))]
-        else:
+        if self.row_names:
             row_masks = [data[self._row_var] == n for n in self.row_names]
+        else:
+            row_masks = [np.repeat(True, len(self.data))]
 
         # Construct masks for the column variable
-        if self._ncol == 1:
-            col_masks = [np.repeat(True, len(self.data))]
-        else:
+        if self.col_names:
             col_masks = [data[self._col_var] == n for n in self.col_names]
+        else:
+            col_masks = [np.repeat(True, len(self.data))]
 
         # Construct masks for the hue variable
-        if len(self._colors) == 1:
-            hue_masks = [np.repeat(True, len(self.data))]
-        else:
+        if self.hue_names:
             hue_masks = [data[self._hue_var] == n for n in self.hue_names]
+        else:
+            hue_masks = [np.repeat(True, len(self.data))]
 
         # Here is the main generator loop
         for (i, row), (j, col), (k, hue) in product(enumerate(row_masks),
@@ -694,8 +701,13 @@ class FacetGrid(Grid):
         # If color was a keyword argument, grab it here
         kw_color = kwargs.pop("color", None)
 
+        if hasattr(func, "__module__"):
+            func_module = str(func.__module__)
+        else:
+            func_module = ""
+
         # Check for categorical plots without order information
-        if func.__module__ == "seaborn.categorical":
+        if func_module == "seaborn.categorical":
             if "order" not in kwargs:
                 warning = ("Using the {} function without specifying "
                            "`order` is likely to produce an incorrect "
@@ -735,9 +747,8 @@ class FacetGrid(Grid):
             plot_args = [v for k, v in plot_data.iteritems()]
 
             # Some matplotlib functions don't handle pandas objects correctly
-            if func.__module__ is not None:
-                if func.__module__.startswith("matplotlib"):
-                    plot_args = [v.values for v in plot_args]
+            if func_module.startswith("matplotlib"):
+                plot_args = [v.values for v in plot_args]
 
             # Draw the plot
             self._facet_plot(func, ax, plot_args, kwargs)
@@ -748,7 +759,7 @@ class FacetGrid(Grid):
         return self
 
     def map_dataframe(self, func, *args, **kwargs):
-        """Like `map` but passes args as strings and inserts data in kwargs.
+        """Like ``.map`` but passes args as strings and inserts data in kwargs.
 
         This method is suitable for plotting with functions that accept a
         long-form DataFrame as a `data` keyword argument and access the
@@ -882,7 +893,7 @@ class FacetGrid(Grid):
 
     def set_xticklabels(self, labels=None, step=None, **kwargs):
         """Set x axis tick labels on the bottom row of the grid."""
-        for ax in self._bottom_axes:
+        for ax in self.axes.flat:
             if labels is None:
                 labels = [l.get_text() for l in ax.get_xticklabels()]
                 if step is not None:
@@ -894,7 +905,7 @@ class FacetGrid(Grid):
 
     def set_yticklabels(self, labels=None, **kwargs):
         """Set y axis tick labels on the left column of the grid."""
-        for ax in self._left_axes:
+        for ax in self.axes.flat:
             if labels is None:
                 labels = [l.get_text() for l in ax.get_yticklabels()]
             ax.set_yticklabels(labels, **kwargs)
@@ -990,7 +1001,9 @@ class FacetGrid(Grid):
         if self.axes.shape == (1, 1):
             return self.axes[0, 0]
         else:
-            raise AttributeError
+            err = ("You must use the `.axes` attribute (an array) when "
+                   "there is more than one plot.")
+            raise AttributeError(err)
 
     @property
     def _inner_axes(self):
@@ -1064,12 +1077,28 @@ class FacetGrid(Grid):
 
 
 class PairGrid(Grid):
-    """Subplot grid for plotting pairwise relationships in a dataset."""
+    """Subplot grid for plotting pairwise relationships in a dataset.
+
+    This class maps each variable in a dataset onto a column and row in a
+    grid of multiple axes. Different axes-level plotting functions can be
+    used to draw bivariate plots in the upper and lower triangles, and the
+    the marginal distribution of each variable can be shown on the diagonal.
+
+    It can also represent an additional level of conditionalization with the
+    ``hue`` parameter, which plots different subets of data in different
+    colors. This uses color to resolve elements on a third dimension, but
+    only draws subsets on top of each other and will not tailor the ``hue``
+    parameter for the specific visualization the way that axes-level functions
+    that accept ``hue`` will.
+
+    See the :ref:`tutorial <grid_tutorial>` for more information.
+
+    """
 
     def __init__(self, data, hue=None, hue_order=None, palette=None,
                  hue_kws=None, vars=None, x_vars=None, y_vars=None,
-                 diag_sharey=True, size=2.5, aspect=1,
-                 despine=True, dropna=True):
+                 diag_sharey=True, height=2.5, aspect=1,
+                 despine=True, dropna=True, size=None):
         """Initialize the plot figure and PairGrid object.
 
         Parameters
@@ -1094,10 +1123,10 @@ class PairGrid(Grid):
         {x, y}_vars : lists of variable names, optional
             Variables within ``data`` to use separately for the rows and
             columns of the figure; i.e. to make a non-square plot.
-        size : scalar, optional
+        height : scalar, optional
             Height (in inches) of each facet.
         aspect : scalar, optional
-            Aspect * size gives the width (in inches) of each facet.
+            Aspect * height gives the width (in inches) of each facet.
         despine : boolean, optional
             Remove the top and right spines from the plots.
         dropna : boolean, optional
@@ -1204,6 +1233,13 @@ class PairGrid(Grid):
 
         """
 
+        # Handle deprecations
+        if size is not None:
+            height = size
+            msg = ("The `size` paramter has been renamed to `height`; "
+                   "please update your code.")
+            warnings.warn(UserWarning(msg))
+
         # Sort out the variables that define the grid
         if vars is not None:
             x_vars = list(vars)
@@ -1226,7 +1262,7 @@ class PairGrid(Grid):
         self.square_grid = self.x_vars == self.y_vars
 
         # Create the figure and the array of subplots
-        figsize = len(x_vars) * size * aspect, len(y_vars) * size
+        figsize = len(x_vars) * height * aspect, len(y_vars) * height
 
         fig, axes = plt.subplots(len(y_vars), len(x_vars),
                                  figsize=figsize,
@@ -1276,7 +1312,8 @@ class PairGrid(Grid):
         ----------
         func : callable plotting function
             Must take x, y arrays as positional arguments and draw onto the
-            "currently active" matplotlib Axes.
+            "currently active" matplotlib Axes. Also needs to accept kwargs
+            called ``color`` and  ``label``.
 
         """
         kw_color = kwargs.pop("color", None)
@@ -1318,10 +1355,9 @@ class PairGrid(Grid):
         Parameters
         ----------
         func : callable plotting function
-            Must take an x array as a positional arguments and draw onto the
-            "currently active" matplotlib Axes. There is a special case when
-            using a ``hue`` variable and ``plt.hist``; the histogram will be
-            plotted with stacked bars.
+            Must take an x array as a positional argument and draw onto the
+            "currently active" matplotlib Axes. Also needs to accept kwargs
+            called ``color`` and  ``label``.
 
         """
         # Add special diagonal axes for the univariate plot
@@ -1345,42 +1381,22 @@ class PairGrid(Grid):
             ax = self.diag_axes[i]
             hue_grouped = self.data[var].groupby(self.hue_vals)
 
-            # Special-case plt.hist with stacked bars
-            if func is plt.hist:
-                plt.sca(ax)
+            plt.sca(ax)
 
-                vals = []
-                for label in self.hue_names:
-                    # Attempt to get data for this level, allowing for empty
-                    try:
-                        vals.append(np.asarray(hue_grouped.get_group(label)))
-                    except KeyError:
-                        vals.append(np.array([]))
+            for k, label_k in enumerate(self.hue_names):
 
-                color = self.palette if fixed_color is None else fixed_color
+                # Attempt to get data for this level, allowing for empty
+                try:
+                    data_k = np.asarray(hue_grouped.get_group(label_k))
+                except KeyError:
+                    data_k = np.array([])
 
-                if "histtype" in kwargs:
-                    func(vals, color=color, **kwargs)
+                if fixed_color is None:
+                    color = self.palette[k]
                 else:
-                    func(vals, color=color, histtype="barstacked", **kwargs)
+                    color = fixed_color
 
-            else:
-                plt.sca(ax)
-
-                for k, label_k in enumerate(self.hue_names):
-
-                    # Attempt to get data for this level, allowing for empty
-                    try:
-                        data_k = hue_grouped.get_group(label_k)
-                    except KeyError:
-                        data_k = np.array([])
-
-                    if fixed_color is None:
-                        color = self.palette[k]
-                    else:
-                        color = fixed_color
-
-                    func(data_k, label=label_k, color=color, **kwargs)
+                func(data_k, label=label_k, color=color, **kwargs)
 
             self._clean_axis(ax)
 
@@ -1395,7 +1411,8 @@ class PairGrid(Grid):
         ----------
         func : callable plotting function
             Must take x, y arrays as positional arguments and draw onto the
-            "currently active" matplotlib Axes.
+            "currently active" matplotlib Axes. Also needs to accept kwargs
+            called ``color`` and  ``label``.
 
         """
         kw_color = kwargs.pop("color", None)
@@ -1440,7 +1457,8 @@ class PairGrid(Grid):
         ----------
         func : callable plotting function
             Must take x, y arrays as positional arguments and draw onto the
-            "currently active" matplotlib Axes.
+            "currently active" matplotlib Axes. Also needs to accept kwargs
+            called ``color`` and  ``label``.
 
         """
         kw_color = kwargs.pop("color", None)
@@ -1486,7 +1504,8 @@ class PairGrid(Grid):
         ----------
         func : callable plotting function
             Must take x, y arrays as positional arguments and draw onto the
-            "currently active" matplotlib Axes.
+            "currently active" matplotlib Axes. Also needs to accept kwargs
+            called ``color`` and  ``label``.
 
         """
 
@@ -1518,8 +1537,8 @@ class PairGrid(Grid):
 class JointGrid(object):
     """Grid for drawing a bivariate plot with marginal univariate plots."""
 
-    def __init__(self, x, y, data=None, size=6, ratio=5, space=.2,
-                 dropna=True, xlim=None, ylim=None):
+    def __init__(self, x, y, data=None, height=6, ratio=5, space=.2,
+                 dropna=True, xlim=None, ylim=None, size=None):
         """Set up the grid of subplots.
 
         Parameters
@@ -1528,7 +1547,7 @@ class JointGrid(object):
             Data or names of variables in ``data``.
         data : DataFrame, optional
             DataFrame when ``x`` and ``y`` are variable names.
-        size : numeric
+        height : numeric
             Size of each side of the figure in inches (it will be square).
         ratio : numeric
             Ratio of joint axes size to marginal axes height.
@@ -1630,7 +1649,7 @@ class JointGrid(object):
             :context: close-figs
 
             >>> g = sns.JointGrid(x="total_bill", y="tip", data=tips,
-            ...                   size=5, ratio=2)
+            ...                   height=5, ratio=2)
             >>> g = g.plot_joint(sns.kdeplot, cmap="Reds_d")
             >>> g = g.plot_marginals(sns.kdeplot, color="r", shade=True)
 
@@ -1645,8 +1664,15 @@ class JointGrid(object):
             >>> g = g.plot_marginals(sns.kdeplot, color="m", shade=True)
 
         """
+        # Handle deprecations
+        if size is not None:
+            height = size
+            msg = ("The `size` parameter has been renamed to `height`; "
+                   "pleaes update your code.")
+            warnings.warn(msg, UserWarning)
+
         # Set up the subplot grid
-        f = plt.figure(figsize=(size, size))
+        f = plt.figure(figsize=(height, height))
         gs = plt.GridSpec(ratio + 1, ratio + 1)
 
         ax_joint = f.add_subplot(gs[1:, :-1])
@@ -1682,12 +1708,6 @@ class JointGrid(object):
                 err = "Could not interpret input '{}'".format(var)
                 raise ValueError(err)
 
-        # Possibly drop NA
-        if dropna:
-            not_na = pd.notnull(x) & pd.notnull(y)
-            x = x[not_na]
-            y = y[not_na]
-
         # Find the names of the variables
         if hasattr(x, "name"):
             xlabel = x.name
@@ -1696,9 +1716,18 @@ class JointGrid(object):
             ylabel = y.name
             ax_joint.set_ylabel(ylabel)
 
-        # Convert the x and y data to arrays for plotting
-        self.x = np.asarray(x)
-        self.y = np.asarray(y)
+        # Convert the x and y data to arrays for indexing and plotting
+        x_array = np.asarray(x)
+        y_array = np.asarray(y)
+
+        # Possibly drop NA
+        if dropna:
+            not_na = pd.notnull(x_array) & pd.notnull(y_array)
+            x_array = x_array[not_na]
+            y_array = y_array[not_na]
+
+        self.x = x_array
+        self.y = y_array
 
         if xlim is not None:
             ax_joint.set_xlim(xlim)
@@ -1788,6 +1817,8 @@ class JointGrid(object):
     def annotate(self, func, template=None, stat=None, loc="best", **kwargs):
         """Annotate the plot with a statistic about the relationship.
 
+        *Deprecated and will be removed in a future version*.
+
         Parameters
         ----------
         func : callable
@@ -1811,6 +1842,10 @@ class JointGrid(object):
             Returns `self`.
 
         """
+        msg = ("JointGrid annotation is deprecated and will be removed "
+               "in a future release.")
+        warnings.warn(UserWarning(msg))
+
         default_template = "{stat} = {val:.2g}; p = {p:.2g}"
 
         # Call the function and determine the form of the return value(s)
@@ -1873,9 +1908,9 @@ class JointGrid(object):
 
 def pairplot(data, hue=None, hue_order=None, palette=None,
              vars=None, x_vars=None, y_vars=None,
-             kind="scatter", diag_kind="hist", markers=None,
-             size=2.5, aspect=1, dropna=True,
-             plot_kws=None, diag_kws=None, grid_kws=None):
+             kind="scatter", diag_kind="auto", markers=None,
+             height=2.5, aspect=1, dropna=True,
+             plot_kws=None, diag_kws=None, grid_kws=None, size=None):
     """Plot pairwise relationships in a dataset.
 
     By default, this function will create a grid of Axes such that each
@@ -1911,17 +1946,18 @@ def pairplot(data, hue=None, hue_order=None, palette=None,
         columns of the figure; i.e. to make a non-square plot.
     kind : {'scatter', 'reg'}, optional
         Kind of plot for the non-identity relationships.
-    diag_kind : {'hist', 'kde'}, optional
-        Kind of plot for the diagonal subplots.
+    diag_kind : {'auto', 'hist', 'kde'}, optional
+        Kind of plot for the diagonal subplots. The default depends on whether
+        ``"hue"`` is used or not.
     markers : single matplotlib marker code or list, optional
         Either the marker to use for all datapoints or a list of markers with
         a length the same as the number of levels in the hue variable so that
         differently colored points will also have different scatterplot
         markers.
-    size : scalar, optional
+    height : scalar, optional
         Height (in inches) of each facet.
     aspect : scalar, optional
-        Aspect * size gives the width (in inches) of each facet.
+        Aspect * height gives the width (in inches) of each facet.
     dropna : boolean, optional
         Drop missing values from the data before plotting.
     {plot, diag, grid}_kws : dicts, optional
@@ -1984,7 +2020,7 @@ def pairplot(data, hue=None, hue_order=None, palette=None,
     .. plot::
         :context: close-figs
 
-        >>> g = sns.pairplot(iris, size=3,
+        >>> g = sns.pairplot(iris, height=3,
         ...                  vars=["sepal_width", "sepal_length"])
 
     Plot different variables in the rows and columns:
@@ -2021,6 +2057,13 @@ def pairplot(data, hue=None, hue_order=None, palette=None,
         ...                  diag_kws=dict(shade=True))
 
     """
+    # Handle deprecations
+    if size is not None:
+        height = size
+        msg = ("The `size` parameter has been renamed to `height`; "
+               "pleaes update your code.")
+        warnings.warn(msg, UserWarning)
+
     if not isinstance(data, pd.DataFrame):
         raise TypeError(
             "'data' must be pandas DataFrame object, not: {typefound}".format(
@@ -2038,7 +2081,7 @@ def pairplot(data, hue=None, hue_order=None, palette=None,
     grid = PairGrid(data, vars=vars, x_vars=x_vars, y_vars=y_vars, hue=hue,
                     hue_order=hue_order, palette=palette,
                     diag_sharey=diag_sharey,
-                    size=size, aspect=aspect, dropna=dropna, **grid_kws)
+                    height=height, aspect=aspect, dropna=dropna, **grid_kws)
 
     # Add the markers here as PairGrid has figured out how many levels of the
     # hue variable are needed and we don't want to duplicate that process
@@ -2055,10 +2098,15 @@ def pairplot(data, hue=None, hue_order=None, palette=None,
         grid.hue_kws = {"marker": markers}
 
     # Maybe plot on the diagonal
+    if diag_kind == "auto":
+        diag_kind = "hist" if hue is None else "kde"
+
+    diag_kws = diag_kws.copy()
     if grid.square_grid:
         if diag_kind == "hist":
             grid.map_diag(plt.hist, **diag_kws)
         elif diag_kind == "kde":
+            diag_kws.setdefault("shade", True)
             diag_kws["legend"] = False
             grid.map_diag(kdeplot, **diag_kws)
 
@@ -2069,8 +2117,8 @@ def pairplot(data, hue=None, hue_order=None, palette=None,
         plotter = grid.map
 
     if kind == "scatter":
-        plot_kws.setdefault("edgecolor", "white")
-        plotter(plt.scatter, **plot_kws)
+        from .relational import scatterplot  # Avoid circular import
+        plotter(scatterplot, **plot_kws)
     elif kind == "reg":
         from .regression import regplot  # Avoid circular import
         plotter(regplot, **plot_kws)
@@ -2082,8 +2130,8 @@ def pairplot(data, hue=None, hue_order=None, palette=None,
     return grid
 
 
-def jointplot(x, y, data=None, kind="scatter", stat_func=stats.pearsonr,
-              color=None, size=6, ratio=5, space=.2,
+def jointplot(x, y, data=None, kind="scatter", stat_func=None,
+              color=None, height=6, ratio=5, space=.2,
               dropna=True, xlim=None, ylim=None,
               joint_kws=None, marginal_kws=None, annot_kws=None, **kwargs):
     """Draw a plot of two variables with bivariate and univariate graphs.
@@ -2102,16 +2150,13 @@ def jointplot(x, y, data=None, kind="scatter", stat_func=stats.pearsonr,
     kind : { "scatter" | "reg" | "resid" | "kde" | "hex" }, optional
         Kind of plot to draw.
     stat_func : callable or None, optional
-        Function used to calculate a statistic about the relationship and
-        annotate the plot. Should map `x` and `y` either to a single value
-        or to a (value, p) tuple. Set to ``None`` if you don't want to
-        annotate the plot.
+        *Deprecated*
     color : matplotlib color, optional
         Color used for the plot elements.
-    size : numeric, optional
+    height : numeric, optional
         Size of the figure (it will be square).
     ratio : numeric, optional
-        Ratio of joint axes size to marginal axes height.
+        Ratio of joint axes height to marginal axes height.
     space : numeric, optional
         Space between the joint and marginal axes
     dropna : bool, optional
@@ -2172,15 +2217,6 @@ def jointplot(x, y, data=None, kind="scatter", stat_func=stats.pearsonr,
         >>> g = sns.jointplot("sepal_width", "petal_length", data=iris,
         ...                   kind="kde", space=0, color="g")
 
-    Use a different statistic for the annotation:
-
-    .. plot::
-        :context: close-figs
-
-        >>> from scipy.stats import spearmanr
-        >>> g = sns.jointplot("size", "total_bill", data=tips,
-        ...                   stat_func=spearmanr, color="m")
-
     Draw a scatterplot, then add a joint density estimate:
 
     .. plot::
@@ -2196,7 +2232,7 @@ def jointplot(x, y, data=None, kind="scatter", stat_func=stats.pearsonr,
         :context: close-figs
 
         >>> x, y = np.random.randn(2, 300)
-        >>> g = (sns.jointplot(x, y, kind="hex", stat_func=None)
+        >>> g = (sns.jointplot(x, y, kind="hex")
         ...         .set_axis_labels("x", "y"))
 
     Draw a smaller figure with more space devoted to the marginal plots:
@@ -2205,7 +2241,7 @@ def jointplot(x, y, data=None, kind="scatter", stat_func=stats.pearsonr,
         :context: close-figs
 
         >>> g = sns.jointplot("total_bill", "tip", data=tips,
-        ...                   size=5, ratio=3, color="g")
+        ...                   height=5, ratio=3, color="g")
 
     Pass keyword arguments down to the underlying plots:
 
@@ -2218,6 +2254,13 @@ def jointplot(x, y, data=None, kind="scatter", stat_func=stats.pearsonr,
         ...                   s=40, edgecolor="w", linewidth=1)
 
     """
+    # Handle deprecations
+    if "size" in kwargs:
+        height = kwargs.pop("size")
+        msg = ("The `size` paramter has been renamed to `height`; "
+               "please update your code.")
+        warnings.warn(msg, UserWarning)
+
     # Set up empty default kwarg dicts
     if joint_kws is None:
         joint_kws = {}
@@ -2231,13 +2274,13 @@ def jointplot(x, y, data=None, kind="scatter", stat_func=stats.pearsonr,
     if color is None:
         color = color_palette()[0]
     color_rgb = mpl.colors.colorConverter.to_rgb(color)
-    colors = [utils.set_hls_values(color_rgb, l=l)
+    colors = [utils.set_hls_values(color_rgb, l=l)  # noqa
               for l in np.linspace(1, 0, 12)]
     cmap = blend_palette(colors, as_cmap=True)
 
     # Initialize the JointGrid object
     grid = JointGrid(x, y, data, dropna=dropna,
-                     size=size, ratio=ratio, space=space,
+                     height=height, ratio=ratio, space=space,
                      xlim=xlim, ylim=ylim)
 
     # Plot the data using the grid
